import{N as m}from"./Navbar-Dkro6IRY.js";import{e as d,an as u,b as a,l,a9 as f,f as _,g as b,v as n,k as y,aP as I}from"./jwt-decode.esm-vMzYWBWe.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-DLiuhEv9.js";import"./constants-DdlI3T3i.js";import"./PhCaretDown.vue-BKJRoIjO.js";import"./os-DmPelCTU.js";import"./router-BBAqj2Hr.js";import"./ts.worker-CH7BZiUP.js";import"./organization-C-GOLbid.js";import"./tables-BFB-VFOv.js";import"./string-BgrCOjj2.js";import"./keyboard-xXmUfOY3.js";import"./projectStore-BDB-yVne.js";import"./project-DWIb0gtr.js";import"./organizationSwitcher-BwesT0ON.js";import"./cascaderStore-DvGVQOlL.js";import"./folder-nvIE8Sks.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-CE7sGxFo.js";import"./member-cnPtnO-T.js";import"./index-BBqkFm79.js";import"./index-BPKpM8oF.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-CIhaVbBZ.js";import"./PhNotePencil.vue-CRsV0yH5.js";import"./PhSignOut.vue-CqRU8ATd.js";import"./index-9fGnhv2O.js";import"./index-Dx5pzTOv.js";import"./PhPlus.vue-B1rZJQ72.js";import"./omniChatStore-Ce3nIm1F.js";import"./contracts.generated-7T9g1q6Z.js";import"./runnerData-K96YRG_Q.js";import"./url-RYQdpdEq.js";import"./colorHelpers-Bh_CU8al.js";import"./uuid-CbyyBDfF.js";import"./PhCopySimple.vue-Ct3pjhys.js";import"./index-wu4K49HN.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="e1e66a50-820b-4e4f-a79b-b01c2a80fc3c",e._sentryDebugIdIdentifier="sentry-dbid-e1e66a50-820b-4e4f-a79b-b01c2a80fc3c")}catch{}})();const v={class:"console-layout"},g={class:"console-content"},w=d({__name:"ConsoleLayout",setup(e){const o=u(),s=a(()=>!!o.params.projectId),p=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),c=a(()=>{const t=o.params.projectId,i=o.params.tableId,r=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:p.value};if(r)return{organizationId:r}});return(t,i)=>{const r=f("RouterView");return b(),_("div",v,[n(m,{"use-cascader":!0,"cascader-props":c.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),y("div",g,[n(r)])])}}}),ao=I(w,[["__scopeId","data-v-62f8634d"]]);export{ao as default};
//# sourceMappingURL=ConsoleLayout-CjTmHV1l.js.map
