import{B as c}from"./BaseLayout-CN5kDuAn.js";import{C as f}from"./ContentLayout-CP38Uxyq.js";import{e as l,an as _,b as i,M as g,a9 as y,n as r,g as s,w as d,v as b,j as w}from"./jwt-decode.esm-vMzYWBWe.js";import{_ as v}from"./BillingAlert.vue_vue_type_script_setup_true_lang-DgjdVHU-.js";import{u as z}from"./projectsStore-KNIxywNu.js";import"./router-BBAqj2Hr.js";import"./ts.worker-CH7BZiUP.js";import"./index-C4WHgmf2.js";import"./member-cnPtnO-T.js";import"./organization-C-GOLbid.js";import"./project-DWIb0gtr.js";import"./tables-BFB-VFOv.js";import"./string-BgrCOjj2.js";import"./folder-nvIE8Sks.js";import"./ant-design-CQmoSA3C.js";import"./cascaderStore-DvGVQOlL.js";import"./organizationSwitcher-BwesT0ON.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="7f8f3d00-1863-4811-99f6-9a5747d0844a",t._sentryDebugIdIdentifier="sentry-dbid-7f8f3d00-1863-4811-99f6-9a5747d0844a")}catch{}})();const q=l({__name:"Organization",setup(t){const e=_(),o=z(),n=i(()=>e.params.organizationId);g(n,a=>{a&&o.fetchedState?.organization?.id!==a&&o.fetchState(a)},{immediate:!0});const u=i(()=>o.fetchedState?.organization),m=i(()=>u.value?.billingMetadata);return(a,h)=>{const p=y("RouterView");return s(),r(c,null,{content:d(()=>[b(f,null,{default:d(()=>[m.value?(s(),r(v,{key:0,"billing-metadata":m.value,"organization-id":n.value},null,8,["billing-metadata","organization-id"])):w("",!0),(s(),r(p,{key:n.value}))]),_:1})]),_:1})}}});export{q as default};
//# sourceMappingURL=Organization-BWjnhngf.js.map
