import{C as e,_ as p}from"./View.vue_vue_type_script_setup_true_lang-D0KioSNy.js";import{e as i,n,g as m,p as a}from"./jwt-decode.esm-vMzYWBWe.js";import{u as s}from"./projectStore-BDB-yVne.js";import"./router-BBAqj2Hr.js";import"./ts.worker-CH7BZiUP.js";import"./fetch-D2Y5MEfD.js";import"./tables-BFB-VFOv.js";import"./string-BgrCOjj2.js";import"./SaveButton-CaLqH7nI.js";import"./ExclamationCircleOutlined-D9M1ojYc.js";import"./CrudView-BxdT2T4q.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-D0Qcgk8C.js";import"./constants-DdlI3T3i.js";import"./url-RYQdpdEq.js";import"./PhDotsThreeVertical.vue-CZ_Vezut.js";import"./index-9fGnhv2O.js";import"./asyncComputed-BAzsb01v.js";import"./omniChatStore-Ce3nIm1F.js";import"./contracts.generated-7T9g1q6Z.js";import"./runnerData-K96YRG_Q.js";import"./colorHelpers-Bh_CU8al.js";import"./uuid-CbyyBDfF.js";import"./PhCopySimple.vue-Ct3pjhys.js";import"./PhPencil.vue-BjLj76ms.js";import"./useCodebaseEvents-Bm9103L3.js";import"./index-C4WHgmf2.js";import"./project-DWIb0gtr.js";import"./organizationSwitcher-BwesT0ON.js";import"./organization-C-GOLbid.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="510ae12c-494f-4283-ac33-0d8fae7ab9a9",o._sentryDebugIdIdentifier="sentry-dbid-510ae12c-494f-4283-ac33-0d8fae7ab9a9")}catch{}})();const J=i({__name:"EnvVars",setup(o){const r=s(),t=new e(r.projectId);return(c,f)=>(m(),n(p,{"env-var-repository":a(t),mode:"console"},null,8,["env-var-repository"]))}});export{J as default};
//# sourceMappingURL=EnvVars-DH7RfJE9.js.map
